Using the Job File Dialog
=========================

The Job File Dialog is used for creating a new Job File, opening an existing Job File, or deleting  a Job File.

1. Select <File | Open Job Files> from the menu  (or: press CTRL / O).  A typical Windows "Open Files" dialog box will appear.


2. To create a new Job, write the name of the new Job file ( the extension  .JOB  will be automatically added) and click the <Open> button  (or:  press the <Enter> key).  The name will be checked and if it is an existing job file name, this existing file will be opened. If this is a new file, a message will inform you that a new file is created.  The file name will appear in the Job Name box. You will have to add at least one existing profile file to the run queue, before saving or running a job.

   To open an existing Job, select the name of the Job file from the file list  and click the <Open> button (or:  select the Job file and press the <Enter> key, or:  double-click the Job name).  The name will appear in the Job Name box.

   Note: Cotton2K supports long file names as in Windows, but because of formatting constraints all file names are restricted to 20 characters (16 characters for the main part of the file name).

3. You may now modify the job by adding or removing profiles. To add a profile to the run queue,  select it in the Profiles list, and then click the <Add Profile> button (or: double-click the profile name in the list).  The profile file name will be removed from the Profiles list and added to the Run queue list.  You may repeat this as many times as necessary.

   To remove a profile from the run queue, select it in the Run queue list, and then click the <Remove Profile> button (or: double-click this profile name in the run queue list). The profile file name will be removed from the Run queue list and added to the Profiles list.  You may repeat this as many times as necessary.

   Note that at least one profile file should be in the run queue before saving or running a job.

4. After that you may save the job file or run the simulation from it. A Job File will be automatically saved before running it, or before exiting the program.

5. When a job is no longer needed, the Open Job File Dialog may be used to delete the job file. This is a standard Windows operation: select the name of the Job file from the file list and press the  <Delete>  key; a message box will appear and ask to confirm the deletion of this file, and then it will be moved to the recycle bin.
